@@ -1,6 +1,7 @@
 from orm.exceptions import MultipleMatches, NoMatch
 from orm.fields import (
     JSON,
+    UUID,
     BigInteger,
     Boolean,
     Date,
@@ -16,7 +17,7 @@ from orm.fields import (
 )
 from orm.models import Model
 
-__version__ = "0.1.8"
+__version__ = "0.1.9"
 __all__ = [
     "NoMatch",
     "MultipleMatches",
@@ -28,10 +29,11 @@ __all__ = [
     "Enum",
     "Float",
     "Integer",
+    "JSON",
     "String",
     "Text",
     "Time",
-    "JSON",
+    "UUID",
     "ForeignKey",
     "Model",
 ]
