@@ -305,6 +305,14 @@ class QuerySet:
         instance.pk = await self.database.execute(expr)
         return instance
 
+    async def get_or_create(self, **kwargs) -> typing.Tuple[typing.Any, bool]:
+        try:
+            instance = await self.get(**kwargs)
+            return instance, False
+        except NoMatch:
+            instance = await self.create(**kwargs)
+            return instance, True
+
     def _prepare_order_by(self, order_by: str):
         reverse = order_by.startswith("-")
         order_by = order_by.lstrip("-")
